
Chart parser
============

The chart parser is used in the NLP pipeline. It produces trees as
output. If desired, the selkie.dep module can be used to convert
constituent-structure trees to dependency trees, using the
head-assignment rules in selkie.head.

.. toctree::
   :titlesonly:

   parser
   tree
   dep
   head
